@@ -25,7 +25,7 @@ const globalContext = require('./global-context.js');
 const op = {};
 exports.op = op;
 
-const CURRENT_VERSION = 21;
+const CURRENT_VERSION = 22;
 const OBJECTS_TABLE_ENTRY_SC_IDX_MAX = 0x000FFFFF;
 const OBJECTS_TABLE_ENTRY_SC_MAX = 0x7FE;
 const OBJECTS_TABLE_ENTRY_SC_SHIFT = 20;
@@ -149,7 +149,7 @@ class BinaryWriteCursor {
       this.uint8(0x80 | (value + 129));
     } else {
       const rest = storageNeeded - 1;
-      const nybble = rest == 4 ? 0 : value >> 8 * rest;
+      const nybble = rest == 4 ? (value >= 0 ? 0 : -1) : value >> 8 * rest;
 
       /* All the other high bits should be the same as the top bit of the
              nybble we keep. Or we have a bug.  */
